==> haskell-puremd5-2.1.4-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pureMD5
version:              2.1.4
visibility:           public
id:                   pureMD5-2.1.4-7aNBlJhCquC8t3r6Ste7mm
key:                  pureMD5-2.1.4-7aNBlJhCquC8t3r6Ste7mm
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  7682127d37e28f487dc7d64e9c2076b0
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pureMD5-2.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pureMD5-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puremd5
hs-libraries:         HSpureMD5-2.1.4-7aNBlJhCquC8t3r6Ste7mm
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puremd5-2.1.4-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pureMD5
version:              2.1.4
visibility:           public
id:                   pureMD5-2.1.4-5F3npGi4HBw7ZAYJR9ZS3M
key:                  pureMD5-2.1.4-5F3npGi4HBw7ZAYJR9ZS3M
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  9c301df98a0c0695326dff47e7763805
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pureMD5-2.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pureMD5-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puremd5
hs-libraries:         HSpureMD5-2.1.4-5F3npGi4HBw7ZAYJR9ZS3M
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    crypto-api-0.13.3-C1qJbx2RCzA2NPKTjJGXlO
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
